@@ -42,7 +42,7 @@ class HttpHeaders(collections.MutableMapping):
         key = key.lower()
         if not key in self.keys:
             raise KeyError(key)
-        vals = [v for k, v in self.headers if k==key]
+        vals = [v for k, v in self.headers if k == key]
         if len(vals) == 1:
             return vals[0]
         else:
@@ -132,6 +132,7 @@ def read_response(conn):
     content_length = int(headers.get('Content-Length', 0))
     body = ""
 
+    # From rfc2616 section 4.4:
     # Messages MUST NOT include both a Content-Length header field and
     # a non-identity transfer-coding. If the message does include a
     # non- identity transfer-coding, the Content-Length MUST be
@@ -255,6 +256,23 @@ class HttpClient(object):
         yield Return(result)
 
 
+# Takes a response return value like:
+# "this is a body"
+# 404
+# (200, "this is a body")
+# (200, {"headers": "here"}, "this is a body")
+#
+# ...and converts that to a full (code, headers, body) tuple.
+def extract_response(value):
+    if isinstance(value, basestring):
+        return (200, HttpHeaders(), value)
+    if isinstance(value, int):
+        return (value, HttpHeaders(), "")
+    if len(value) == 2:
+        return (value[0], HttpHeaders(), value[1])
+    return value
+
+
 import monocle
 if monocle._stack_name == 'twisted':
     from monocle.twisted_stack.network.http import *
